PiWeatherRock Configuration

PiWeatherRock Configuration Page
Basic
Advanced
Basic Settings
API Key: This is your Dark Sky API key. Click the link and sign-up for free to retrieve it.
Latitude: Click the link. Right click on desired location on the map, and click "show address" for coordinates.
Longitude: Click the link. Right click on desired location on the map, and click "show address" for coordinates.
Units: Information about units can be found by clicking the link, and searching for "units" section.
Language: Information about languages can be found by clicking the link, and searching for "languages" section.
Fullscreen: Use fullscreen when running on a TV or similar device with a higher resolution.
12/24 hour display: Set true for 12 hour display, false for 24 hour display.
Icon Offset: If the weather icons are overlapping the text, try adjusting this value. Negative values raise the icon.
Frequency: Number of seconds between API calls. Free Dark Sky access only allows for 1,000 calls/day (every 86.4 seconds).
Weather Info
Pause: The number of seconds to show the "weather info" screen.
Delay: The number of seconds to wait before showing the "weather info" screen.
Daily Weather
Off
On
Pause: The number of seconds to show the "daily weather" screen.
Hourly Weather
Off
On
Pause: The number of seconds to show the "hourly weather" screen.
Log
Log Level: Change this to 'DEBUG', if you need to troubleshoot issues.
Go to Log > Click this link to show the log.